@@ -1,7 +1,7 @@
 package Business::ID::NIK;
 
-our $DATE = '2018-02-07'; # DATE
-our $VERSION = '0.090'; # VERSION
+our $DATE = '2018-04-08'; # DATE
+our $VERSION = '0.092'; # VERSION
 
 use 5.010001;
 use warnings;
@@ -111,7 +111,7 @@ Business::ID::NIK - Parse Indonesian citizenship registration number (NIK)
 
 =head1 VERSION
 
-This document describes version 0.090 of Business::ID::NIK (from Perl distribution Business-ID-NIK), released on 2018-02-07.
+This document describes version 0.092 of Business::ID::NIK (from Perl distribution Business-ID-NIK), released on 2018-04-08.
 
 =head1 SYNOPSIS
 
@@ -194,6 +194,11 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Business::ID::NKK> to parse family card number (nomor kartu keluarga, nomor
+KK, NKK)
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
